pub struct RepoChecks {
pub protected: bool,
pub license: bool,
pub old_branches: (bool, i64),
pub branch_filter: Option<Regex>,
}Expand description
A holder for things that can be checked for a repository
Fields
protected: boolCheck if the main branch is protected
license: boolCheck the license of the repository
old_branches: (bool, i64)Check for old branches. The tuple is whether to enable it, and the minimum number of days of inactivity
branch_filter: Option<Regex>A regex filter for the branches